@@ -2,7 +2,7 @@
 #'
 #'Compute the root mean square error for an array of forecasts and an array of
 #'observations. The RMSEs are computed along time_dim, the dimension which 
-#'corresponds to the startdate dimension. If comp_dim is given, the RMSEs are 
+#'corresponds to the start date dimension. If comp_dim is given, the RMSEs are 
 #'computed only if obs along the comp_dim dimension are complete between 
 #'limits[1] and limits[2], i.e. there are no NAs between limits[1] and 
 #'limits[2]. This option can be activated if the user wishes to account only 
@@ -10,18 +10,19 @@
 #'all leadtimes.\cr
 #'The confidence interval is computed by the chi2 distribution.\cr
 #'
-#'@param exp A named numeric array of experimental data, with at least two 
-#'  dimensions 'time_dim' and 'dat_dim'. It can also be a vector with the 
-#'  same length as 'obs', then the vector will automatically be 'time_dim' and 
-#'  'dat_dim' will be 1.
+#'@param exp A named numeric array of experimental data, with at least 
+#'  'time_dim' dimension. It can also be a vector with the same length as 'obs'.
 #'@param obs A named numeric array of observational data, same dimensions as  
-#'  parameter 'exp' except along dat_dim. It can also be a vector with the same
-#'  length as 'exp', then the vector will automatically be 'time_dim' and 
-#'  'dat_dim' will be 1.
+#'  parameter 'exp' except along 'dat_dim' and 'memb_dim'. It can also be a 
+#'  vector with the same length as 'exp'.
 #'@param time_dim A character string indicating the name of dimension along  
 #'  which the correlations are computed. The default value is 'sdate'.
-#'@param dat_dim A character string indicating the name of member (nobs/nexp) 
-#'  dimension. The default value is 'dataset'.
+#'@param memb_dim A character string indicating the name of the member dimension
+#'  to compute the ensemble mean; it should be set to NULL if the input data are
+#'  already the ensemble mean. The default value is NULL.
+#'@param dat_dim A character string indicating the name of dataset or member 
+#'  (nobs/nexp) dimension. The datasets of exp and obs will be paired and 
+#'  computed RMS for each pair. The default value is NULL.
 #'@param comp_dim A character string indicating the name of dimension along which
 #'  obs is taken into account only if it is complete. The default value
 #'  is NULL.
@@ -29,8 +30,8 @@
 #'  be completed. The default value is c(1, length(comp_dim dimension)).
 #'@param conf A logical value indicating whether to retrieve the confidence 
 #'  intervals or not. The default value is TRUE.
-#'@param conf.lev A numeric indicating the confidence level for the 
-#'  regression computation. The default value is 0.95.
+#'@param alpha A numeric indicating the significance level for the statistical
+#'  significance test. The default value is 0.05.
 #'@param ncores An integer indicating the number of cores to use for parallel 
 #'  computation. The default value is NULL.
 #'
@@ -38,7 +39,8 @@
 #'A list containing the numeric arrays with dimension:\cr 
 #'  c(nexp, nobs, all other dimensions of exp except time_dim).\cr
 #'nexp is the number of experiment (i.e., dat_dim in exp), and nobs is the 
-#'number of observation (i.e., dat_dim in obs).\cr
+#'number of observation (i.e., dat_dim in obs). If dat_dim is NULL, nexp and 
+#'nobs are omitted.\cr
 #'\item{$rms}{
 #'  The root mean square error. 
 #'}
@@ -51,24 +53,32 @@
 #'
 #'@examples
 #'# Load sample data as in Load() example:
-#'  set.seed(1)
-#'  exp1 <- array(rnorm(120), dim = c(dataset = 3, sdate = 5, ftime = 2, lon = 1, lat = 4))
-#'  set.seed(2)
-#'  obs1 <- array(rnorm(80),  dim = c(dataset = 2, sdate = 5, ftime = 2, lon = 1, lat = 4))
-#'  set.seed(2)
-#'  na <- floor(runif(10, min = 1, max = 80))
-#'  obs1[na] <- NA
-#'  res <- RMS(exp1, obs1, comp_dim = 'ftime')
-#'  # Renew example when Ano and Smoothing are ready
+#'example(Load)
+#'clim <- Clim(sampleData$mod, sampleData$obs)
+#'ano_exp <- Ano(sampleData$mod, clim$clim_exp)
+#'ano_obs <- Ano(sampleData$obs, clim$clim_obs)
+#'smooth_ano_exp <- Smoothing(ano_exp, runmeanlen = 12, time_dim = 'ftime')
+#'smooth_ano_obs <- Smoothing(ano_obs, runmeanlen = 12, time_dim = 'ftime')
+#'res <- RMS(smooth_ano_exp, smooth_ano_obs, memb_dim = 'member', 
+#'           comp_dim = 'ftime', limits = c(7, 54))
 #'
-#'@rdname RMS
+#'# Synthetic data:
+#'exp1 <- array(rnorm(120), dim = c(dat = 3, sdate = 10, ftime = 4))
+#'obs1 <- array(rnorm(80),  dim = c(dat = 2, sdate = 10, ftime = 4))
+#'na <- floor(runif(10, min = 1, max = 80))
+#'obs1[na] <- NA
+#'res1 <- RMS(exp1, obs1, comp_dim = 'ftime', dat_dim = 'dat')
+#'  
+#'exp2 <- array(rnorm(20), dim = c(sdate = 5, member = 4))
+#'obs2 <- array(rnorm(10),  dim = c(sdate = 5, member = 2))
+#'res2 <- RMS(exp2, obs2, memb_dim = 'member')
+#'  
 #'@import multiApply
 #'@importFrom ClimProjDiags Subset
 #'@importFrom stats qchisq
 #'@export
-RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
-                comp_dim = NULL, limits = NULL, 
-                conf = TRUE, conf.lev = 0.95, ncores = NULL) {       
+RMS <- function(exp, obs, time_dim = 'sdate', memb_dim = NULL, dat_dim = NULL, 
+                comp_dim = NULL, limits = NULL, conf = TRUE, alpha = 0.05, ncores = NULL) {       
   # Check inputs 
   ## exp and obs (1)
   if (is.null(exp) | is.null(obs)) {
@@ -79,26 +89,22 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
   }
   if (is.null(dim(exp)) & is.null(dim(obs))) {  #is vector
     if (length(exp) == length(obs)) {
-      exp <- array(exp, dim = c(length(exp), 1))
-      names(dim(exp)) <- c(time_dim, dat_dim)
-      obs <- array(obs, dim = c(length(obs), 1))
-      names(dim(obs)) <- c(time_dim, dat_dim)
+      exp <- array(exp, dim = c(length(exp)))
+      names(dim(exp)) <- c(time_dim)
+      obs <- array(obs, dim = c(length(obs)))
+      names(dim(obs)) <- c(time_dim)
     } else {
-    stop(paste0("Parameter 'exp' and 'obs' must be array with as least two ",
-                "dimensions time_dim and dat_dim, or vector of same length."))
+      stop(paste0("Parameter 'exp' and 'obs' must be array with as least two ",
+                  "dimensions time_dim and dat_dim, or vector of same length."))
     }
   } else if (is.null(dim(exp)) | is.null(dim(obs))) {
     stop(paste0("Parameter 'exp' and 'obs' must be array with as least two ",
                 "dimensions time_dim and dat_dim, or vector of same length."))
   }
-  if(any(is.null(names(dim(exp))))| any(nchar(names(dim(exp))) == 0) |
-     any(is.null(names(dim(obs))))| any(nchar(names(dim(obs))) == 0)) {
+  if (any(is.null(names(dim(exp)))) | any(nchar(names(dim(exp))) == 0) |
+      any(is.null(names(dim(obs)))) | any(nchar(names(dim(obs))) == 0)) {
     stop("Parameter 'exp' and 'obs' must have dimension names.")
   }
-  if(!all(names(dim(exp)) %in% names(dim(obs))) | 
-     !all(names(dim(obs)) %in% names(dim(exp)))) {
-    stop("Parameter 'exp' and 'obs' must have same dimension name")
-  }
   ## time_dim
   if (!is.character(time_dim) | length(time_dim) > 1) {
     stop("Parameter 'time_dim' must be a character string.")
@@ -106,6 +112,15 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
   if (!time_dim %in% names(dim(exp)) | !time_dim %in% names(dim(obs))) {
     stop("Parameter 'time_dim' is not found in 'exp' or 'obs' dimension.")
   }
+  ## memb_dim
+  if (!is.null(memb_dim)) {
+    if (!is.character(memb_dim) | length(memb_dim) > 1) {
+      stop("Parameter 'memb_dim' must be a character string.")
+    }
+    if (!memb_dim %in% names(dim(exp)) & !memb_dim %in% names(dim(obs))) {
+      stop("Parameter 'memb_dim' is not found in 'exp' nor 'obs' dimension.")
+    }
+  }
   ## dat_dim
   if (!is.null(dat_dim)) {
     if (!is.character(dat_dim) | length(dat_dim) > 1) {
@@ -140,9 +155,9 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
   if (!is.logical(conf) | length(conf) > 1) {
     stop("Parameter 'conf' must be one logical value.")
   }
-  ## conf.lev
-  if (!is.numeric(conf.lev) | conf.lev < 0 | conf.lev > 1 | length(conf.lev) > 1) {
-    stop("Parameter 'conf.lev' must be a numeric number between 0 and 1.")
+  ## alpha
+  if (!is.numeric(alpha) | alpha < 0 | alpha > 1 | length(alpha) > 1) {
+    stop("Parameter 'alpha' must be a numeric number between 0 and 1.")
   }
   ## ncores
   if (!is.null(ncores)) {
@@ -151,22 +166,44 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
       stop("Parameter 'ncores' must be a positive integer.")
     }
   } 
+  
   ## exp and obs (2)
   name_exp <- sort(names(dim(exp)))
   name_obs <- sort(names(dim(obs)))
+  if (!is.null(memb_dim)) {
+    if (memb_dim %in% name_exp) {
+      name_exp <- name_exp[-which(name_exp == memb_dim)]
+    }
+    if (memb_dim %in% name_obs) {
+      name_obs <- name_obs[-which(name_obs == memb_dim)]
+    }
+  }
   if (!is.null(dat_dim)) {
     name_exp <- name_exp[-which(name_exp == dat_dim)]
     name_obs <- name_obs[-which(name_obs == dat_dim)]
   }
-  if(!all(dim(exp)[name_exp] == dim(obs)[name_obs])) {
+  if (!all(name_exp == name_obs)) {
+    stop("Parameter 'exp' and 'obs' must have the same dimension names.")
+  }
+  if (!identical(dim(exp)[name_exp], dim(obs)[name_obs])) {
     stop(paste0("Parameter 'exp' and 'obs' must have same length of ",
-                "all dimension except 'dat_dim'."))
+                "all dimensions except 'dat_dim' and 'memb_dim'."))
   }
   if (dim(exp)[time_dim] < 2) {
     stop("The length of time_dim must be at least 2 to compute RMS.")
   }
-
-
+  
+  ###############################
+  ## Ensemble mean
+  if (!is.null(memb_dim)) {
+    if (memb_dim %in% names(dim(exp))) {
+      exp <- MeanDims(exp, memb_dim, na.rm = T)
+    }
+    if (memb_dim %in% names(dim(obs))) {
+      obs <- MeanDims(obs, memb_dim, na.rm = T)
+    }
+  }
+  
   ###############################
   # Sort dimension
   name_exp <- names(dim(exp))
@@ -195,21 +232,20 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
                                   c(time_dim, dat_dim)),
                fun = .RMS, 
                time_dim = time_dim, dat_dim = dat_dim,
-               conf = conf, conf.lev = conf.lev, ncores_input = ncores,
+               conf = conf, alpha = alpha,
                ncores = ncores)
   return(res)
 }
 
-.RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
-                 conf = TRUE, conf.lev = 0.95, ncores_input = NULL) {
+.RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = NULL, conf = TRUE, alpha = 0.05) { 
   if (is.null(dat_dim)) {
     # exp: [sdate]
     # obs: [sdate]
     nexp <- 1
     nobs <- 1
     ini_dims <- dim(exp)
-    dim(exp) <- c(ini_dims, dat_dim = 1)
-    dim(obs) <- c(ini_dims, dat_dim = 1)
+    dim(exp) <- c(ini_dims, dat = 1)
+    dim(obs) <- c(ini_dims, dat = 1)
   } else {
     # exp: [sdate, dat_exp]
     # obs: [sdate, dat_obs]
@@ -218,10 +254,9 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
   }
   
   dif <- array(dim = c(dim(exp)[1], nexp = nexp, nobs = nobs))
-  chi <- array(dim = c(nexp = nexp, nobs = nobs))
 
   if (conf) {
-    conflow <- (1 - conf.lev) / 2
+    conflow <- alpha / 2
     confhigh <- 1 - conflow
     conf.lower <- array(dim = c(nexp = nexp, nobs = nobs))
     conf.upper <- array(dim = c(nexp = nexp, nobs = nobs))
@@ -232,12 +267,17 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
     dif[, , i] <- sapply(1:nexp, function(x) {exp[, x] - obs[, i]})
   }
 
-  rms <- apply(dif^2, c(2, 3), mean, na.rm = TRUE)^0.5  #array(dim = c(_exp, nobs))
-
-  if (conf) {
-    #eno <- Eno(dif, 1) #count effective sample along sdate. dim = c(nexp, nobs)
-    eno <- Eno(dif, time_dim, ncores = ncores_input) #change to this line when Eno() is done
+  rms <- colMeans(dif^2, na.rm = TRUE)^0.5  # [nexp, nobs]
 
+  if (conf) {  #NOTE: pval and sign also need
+    #count effective sample along sdate. eno: c(nexp, nobs)
+#    eno <- Eno(dif, time_dim)  # slower than for loop below?
+    eno <- array(dim = c(nexp = nexp, nobs = nobs))
+    for (n_obs in 1:nobs) {
+      for (n_exp in 1:nexp) {
+        eno[n_exp, n_obs] <- .Eno(dif[, n_exp, n_obs], na.action = na.pass)
+      }
+    }
     # conf.lower
     chi <- sapply(1:nobs, function(i) {
                              qchisq(confhigh, eno[, i] - 1)
@@ -251,6 +291,16 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
     conf.upper <- (eno * rms ** 2 / chi) ** 0.5
   }
 
+#NOTE: Not sure if the calculation is correct. p_val is reasonable compared to the chi-square chart though.
+#  if (pval | sign) {
+#    chi <- array(dim = c(nexp = nexp, nobs = nobs))
+#    for (i in 1:nobs) {
+#      chi[, i] <- sapply(1:nexp, function(x) {sum((obs[, i] - exp[, x])^2 / exp[, x])})
+#    }
+#    p_val <- pchisq(chi, eno - 1, lower.tail = FALSE)
+#    if (sign) signif <- p_val <= alpha 
+#  }
+
   ###################################
   # Remove nexp and nobs if dat_dim = NULL
   if (is.null(dat_dim)) {
@@ -262,13 +312,9 @@ RMS <- function(exp, obs, time_dim = 'sdate', dat_dim = 'dataset',
   }
 
   ###################################
-
-  if (conf) {
-    res <- list(rms = rms, conf.lower = conf.lower, conf.upper = conf.upper)
-  } else {
-    res <- list(rms = rms)
-  } 
+  res <- list(rms = rms)
+  if (conf) res <- c(res, list(conf.lower = conf.lower, conf.upper = conf.upper))
 
   return(res)
 
-}
\ No newline at end of file
+}
