@@ -15,12 +15,14 @@
 #' points along 'time_dim' dimension. The default value is 1.
 #'@param polydeg A positive integer indicating the degree of polynomial 
 #'  regression. The default value is 1.
+#'@param alpha A numeric indicating the significance level for the statistical
+#'  significance test. The default value is 0.05. 
 #'@param conf A logical value indicating whether to retrieve the confidence 
 #'  intervals or not. The default value is TRUE.
-#'@param conf.lev A numeric indicating the confidence level for the 
-#'  regression computation. The default value is 0.95.
 #'@param pval A logical value indicating whether to compute the p-value or not. 
 #'  The default value is TRUE.
+#'@param sign A logical value indicating whether to retrieve the statistical
+#'  significance based on 'alpha'. The default value is FALSE.
 #'@param ncores An integer indicating the number of cores to use for parallel 
 #'  computation. The default value is NULL.
 #'
@@ -37,7 +39,7 @@
 #'  A numeric array with the first dimension 'stats', followed by the same 
 #'  dimensions as parameter 'data' except the 'time_dim' dimension. The length
 #'  of the 'stats' dimension should be \code{polydeg + 1}, containing the 
-#'  lower limit of the \code{conf.lev}\% confidence interval for all the 
+#'  lower limit of the \code{(1-alpha)}\% confidence interval for all the 
 #'  regression coefficients with the same order as \code{$trend}. Only present 
 #'  \code{conf = TRUE}.
 #'}
@@ -45,7 +47,7 @@
 #'  A numeric array with the first dimension 'stats', followed by the same 
 #'  dimensions as parameter 'data' except the 'time_dim' dimension. The length
 #'  of the 'stats' dimension should be \code{polydeg + 1}, containing the 
-#'  upper limit of the \code{conf.lev}\% confidence interval for all the 
+#'  upper limit of the \code{(1-alpha)}\% confidence interval for all the 
 #'  regression coefficients with the same order as \code{$trend}. Only present 
 #'  \code{conf = TRUE}.
 #'}
@@ -54,6 +56,9 @@
 #'  'stats' is 1, followed by the same dimensions as parameter 'data' except 
 #'  the 'time_dim' dimension. Only present if \code{pval = TRUE}.
 #'}
+#'\item{$sign}{
+#'  The statistical significance. Only present if \code{sign = TRUE}.
+#'}
 #'\item{$detrended}{
 #'  A numeric array with the same dimensions as paramter 'data', containing the 
 #'  detrended values along the 'time_dim' dimension.
@@ -69,8 +74,8 @@
 #'@import multiApply
 #'@importFrom stats anova
 #'@export
-Trend <- function(data, time_dim = 'ftime', interval = 1, polydeg = 1,
-                  conf = TRUE, conf.lev = 0.95, pval = TRUE, ncores = NULL) {
+Trend <- function(data, time_dim = 'ftime', interval = 1, polydeg = 1, alpha = 0.05,
+                  conf = TRUE, pval = TRUE, sign = FALSE, ncores = NULL) {
 
   # Check inputs 
   ## data
@@ -103,18 +108,22 @@ Trend <- function(data, time_dim = 'ftime', interval = 1, polydeg = 1,
       length(polydeg) > 1) {
     stop("Parameter 'polydeg' must be a positive integer.")
   }
+  ## alpha
+  if (!is.numeric(alpha) | any(alpha < 0) | any(alpha > 1) | length(alpha) > 1) {
+    stop("Parameter 'alpha' must be a numeric number between 0 and 1.")
+  }
   ## conf
   if (!is.logical(conf) | length(conf) > 1) {
     stop("Parameter 'conf' must be one logical value.")
   }
-  ## conf.lev
-  if (!is.numeric(conf.lev) | conf.lev < 0 | conf.lev > 1 | length(conf.lev) > 1) {
-    stop("Parameter 'conf.lev' must be a numeric number between 0 and 1.")
-  }
   ## pval
   if (!is.logical(pval) | length(pval) > 1) {
     stop("Parameter 'pval' must be one logical value.")
   }
+  ## sign
+  if (!is.logical(sign) | length(sign) > 1) {
+    stop("Parameter 'sign' must be one logical value.")
+  }
   ## ncores
   if (!is.null(ncores)) {
     if (!is.numeric(ncores)) {
@@ -126,32 +135,29 @@ Trend <- function(data, time_dim = 'ftime', interval = 1, polydeg = 1,
 
   ###############################
   # Calculate Trend
-  if (conf & pval) {
-    output_dims <- list(trend = 'stats', conf.lower = 'stats',
-                        conf.upper = 'stats', p.val = 'stats', detrended = time_dim)
-  } else if (conf & !pval) {
-    output_dims <- list(trend = 'stats', conf.lower = 'stats',
-                        conf.upper = 'stats', detrended = time_dim)
-  } else if (!conf & pval) {
-    output_dims <- list(trend = 'stats', p.val = 'stats', detrended = time_dim)
-  } else {
-    output_dims <- list(trend = 'stats', detrended = time_dim)
-  }
+
+  ## output_dims
+  output_dims <- list(trend = 'stats')
+  if (conf) output_dims <- c(output_dims, list(conf.lower = 'stats', conf.upper = 'stats'))
+  if (pval) output_dims <- c(output_dims, list(p.val = 'stats'))
+  if (sign) output_dims <- c(output_dims, list(sign = 'stats'))
+
+  output_dims <- c(output_dims, list(detrended = time_dim))
   
   output <- Apply(list(data),
                   target_dims = time_dim,
                   fun = .Trend,
                   output_dims = output_dims,
                   interval = interval, 
-                  polydeg = polydeg, conf = conf,
-                  conf.lev = conf.lev, pval = pval,
+                  polydeg = polydeg, alpha = alpha, conf = conf,
+                  pval = pval, sign = sign,
                   ncores = ncores)
 
   return(invisible(output))
 }
 
-.Trend <- function(x, interval = 1, polydeg = 1,
-                   conf = TRUE, conf.lev = 0.95, pval = TRUE) {
+.Trend <- function(x, interval = 1, polydeg = 1, alpha = 0.05,
+                   conf = TRUE, pval = TRUE, sign = FALSE) {
   # x: [ftime]
 
   mon <- seq(x) * interval
@@ -168,12 +174,14 @@ Trend <- function(data, time_dim = 'ftime', interval = 1, polydeg = 1,
     trend <- lm.out$coefficients  #intercept, slope1, slope2,...
 
     if (conf) {
-      conf.lower <- confint(lm.out, level = conf.lev)[, 1]
-      conf.upper <- confint(lm.out, level = conf.lev)[, 2]
+      conf.lower <- confint(lm.out, level = (1 - alpha))[, 1]
+      conf.upper <- confint(lm.out, level = (1 - alpha))[, 2]
     }
 
-    if (pval) {
-      p.val <- as.array(stats::anova(lm.out)$'Pr(>F)'[1])
+    if (pval | sign) {
+      p.value <- as.array(stats::anova(lm.out)$'Pr(>F)'[1])
+      if (pval) p.val <- p.value
+      if (sign) signif <- !is.na(p.value) & p.value <= alpha 
     }
 
     detrended <- c()
@@ -189,21 +197,16 @@ Trend <- function(data, time_dim = 'ftime', interval = 1, polydeg = 1,
       conf.upper <- rep(NA, polydeg + 1)
     }
 
-    if (pval) {
-      p.val <- as.array(NA)
-    }
+    if (pval) p.val <- as.array(NA)
+    if (sign) signif <- as.array(FALSE)
 
   }
-  if (conf & pval) {
-    return(list(trend = trend, conf.lower = conf.lower, conf.upper = conf.upper, 
-                p.val = p.val, detrended = detrended))
-  } else if (conf & !pval) {
-    return(list(trend = trend, conf.lower = conf.lower, conf.upper = conf.upper,
-                detrended = detrended))
-  } else if (!conf & pval) {
-    return(list(trend = trend, p.val = p.val, detrended = detrended))
-  } else {
-    return(list(trend = trend, detrended = detrended))
-  }
 
+  output <- list(trend = trend)
+  if (conf) output <- c(output, list(conf.lower = conf.lower, conf.upper = conf.upper))
+  if (pval) output <- c(output, list(p.val = p.val))
+  if (sign) output <- c(output, list(sign = signif))
+  output <- c(output, list(detrended = detrended))
+
+  return(output)
 }
